using System.Collections;
using System.Collections.Generic;
using TMPro;
using UnityEditor.SearchService;
using UnityEngine;
using UnityEngine.SceneManagement;

public class Ball : MonoBehaviour
{
    /// <summary>
    /// A reference to the gameManager object, which controls the game state.
    /// </summary>
    GameManager gameManager;

    // Awake is called before Start.
    private void Awake()
    {
        gameManager = FindObjectOfType<GameManager>();
    }

    // Start is called once during the first frame.
    void Start()
    {
        // randomly respon the ball somewhere
        RandomRespawn();
    }

    // Update is called once per frame
    void Update()
    {
        // dectect if the ball is out of the map every frame
        FallDetection();
    }

    /// <summary>
    /// Respawn the ball in a new, random position.
    /// Called at the beginning of the game, and whenever the ball falls off
    /// the map.
    /// </summary>
    void RandomRespawn()
    {
        // x (-24  to 24), y (>0.5), z (-24, 24)
        Vector3 randomSpawnPos = new Vector3(0, 2, 0);
        transform.position = randomSpawnPos;
    }

    /// <summary>
    /// Checks to see if the ball fell out of the map. If it did,
    /// add 3 kicks to the score (for penalty) and respawn the ball.
    /// </summary>
    void FallDetection()
    {
        if (transform.position.y < 0)
        {
            Debug.Log("ADD 3 POINTS FOR OUT OF MAP");
            RandomRespawn();
            gameManager.IncrementBallCounter(3);
        }
    }

    /// <summary>
    /// Unity default collision detector. Check what
    /// was collided with and take action accordingly.
    /// </summary>
    /// <param name="other"></param>
    void OnCollisionEnter(Collision other)
    {
        /* Play a bounce sound */
        AudioSource.PlayClipAtPoint(Resources.Load<AudioClip>("bounce_effect"), transform.position);

        //Debug.Log("Hit "+other.gameObject.name);
        if (other.gameObject.name == "Pole" || other.gameObject.name == "Flag")
        {
            gameManager.EndGame();
            Destroy(gameObject);
        }
    }
}
