using System.Collections;
using System.Collections.Generic;
using TMPro;
using UnityEngine;
using UnityEngine.SceneManagement;

public class GameManager : MonoBehaviour
{
    [SerializeField] TextMeshProUGUI KickText;
    [SerializeField] TextMeshProUGUI GameOverText;

    private int points;

    /// <summary>
    /// A helper function used to increase the number of points.
    /// </summary>
    /// <param name="pointsToAdd">The number of points to add to the score.</param>
    public void IncrementBallCounter(int pointsToAdd)
    {
        KickText.text = "Kicks: " + points;
    }

    /// <summary>
    /// A function to be used in order to end the game.
    /// </summary>
    public void EndGame()
    {
        /* Hide any existing UI */
        KickText.gameObject.SetActive(false);

        /* Display the end game UI */
        GameOverText.gameObject.SetActive(true);
        GameOverText.text = "Game Over\nScore: " + points + "\n\nReloading game in 5 seconds.";

        /* Play applause */
        AudioSource.PlayClipAtPoint(Resources.Load<AudioClip>("golf_clap"), FindObjectOfType<Player>().transform.position);

        /* Restart the level */
        StartCoroutine(EndGameCoroutine());
    }

    /// <summary>
    /// A helper coroutine used to end the game after a specified
    /// timeout amount.
    /// </summary>
    /// <param name="timeout">The amount of seconds to wait before resetting the level.</param>
    /// <returns></returns>
    IEnumerator EndGameCoroutine()
    {
        /* Countdown */
        float timeRemaining = 5.0f;
        while (timeRemaining >= 0)
        {
            timeRemaining -= Time.deltaTime;
            GameOverText.text = "Game Over\nScore: " + points + "\n\nReloading game in " + timeRemaining.ToString("f1") + " seconds.";
            yield return new WaitForEndOfFrame();
        }

        /* Reload scene */
        var scene = SceneManager.GetActiveScene();
        SceneManager.LoadScene(scene.name);
    }
}
