using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Player : MonoBehaviour
{

    public float MovementSpeed;
    public float RotationSpeed;
    public float BallRadius;
    public float KickStrength = 10f;

    private CharacterController characterController;

    private void Awake()
    {
        characterController = GetComponent<CharacterController>();
    }

    // Update is called once per frame
    void Update()
    {
        /* Create a movement direction */
        float horizontal = Input.GetAxis("Horizontal");
        float vertical = Input.GetAxis("Vertical");
        HandleMovement(horizontal, vertical);

        /* Handle kicking */
        HandleKick();
    }

    /// <summary>
    /// Move the player. Uses the two axes to calculate a
    /// movement direction based on their value.
    /// </summary>
    /// <param name="horizontalAxis">The amount to rotate the player.</param>
    /// <param name="verticalAxis">The amount to move the player forward / backward.</param>
    void HandleMovement(float horizontalAxis, float verticalAxis)
    {
        Vector3 forwardMovement = transform.forward * verticalAxis * MovementSpeed * Time.deltaTime;
        float rotationAmount = horizontalAxis * RotationSpeed * Time.deltaTime;

        /* Tank Controls */
        characterController.Move(forwardMovement);
        characterController.Move(transform.up * Physics.gravity.y * Time.deltaTime);
        transform.Rotate(new Vector3(0f, rotationAmount, 0f));
    }

    /// <summary>
    /// Handle the kicking action of the player.
    /// </summary>
    void HandleKick()
    {
        bool ballIsNearby = false;
        Rigidbody ball = null;

        /* Use an overlapsphere to see if the ball is nearby */
        foreach (var collider in Physics.OverlapSphere(transform.position, BallRadius))
        {
            if (collider.gameObject.TryGetComponent<Ball>(out var ballObject))
            {
                /* This is the ball. */
                ballIsNearby = true;
                ball = ballObject.GetComponent<Rigidbody>();
                break;
            }
        }

        /* The ball is nearby - check if we should kick it */
        if (ballIsNearby && Input.GetMouseButtonDown(0))
        {
            ball.AddForce(new Vector3(ball.position.x - transform.position.x, 0f, ball.position.z - transform.position.z).normalized * 2.0f * KickStrength + Vector3.up * KickStrength);
            FindObjectOfType<GameManager>().IncrementBallCounter(1);
            AudioSource.PlayClipAtPoint(Resources.Load<AudioClip>("bounce_effect"), ball.position);
        }
    }
}
